@@ -44,8 +44,8 @@
         (magit-display-buffer-noselect t))
     (apply (intern (format "%s-setup-buffer"
                            (substring (symbol-name mode) 0 -5)))
-           (--map (bookmark-prop-get bookmark it)
-                  (get mode 'magit-bookmark-variables)))))
+           (mapcar (##bookmark-prop-get bookmark %)
+                   (get mode 'magit-bookmark-variables)))))
 
 ;;; Diff
 ;;;; Diff
