@@ -42,10 +42,9 @@
    ("p" "privately (.git/info/exclude)"
     magit-gitignore-in-gitdir)
    ("g" magit-gitignore-on-system
-    :if (lambda () (magit-get "core.excludesfile"))
-    :description (lambda ()
-                   (format "privately for all repositories (%s)"
-                           (magit-get "core.excludesfile"))))]
+    :if (##magit-get "core.excludesfile")
+    :description (##format "privately for all repositories (%s)"
+                           (magit-get "core.excludesfile")))]
   ["Skip worktree"
    (7 "w" "do skip worktree"     magit-skip-worktree)
    (7 "W" "do not skip worktree" magit-no-skip-worktree)]
@@ -116,11 +115,12 @@ Rules that are defined in that file affect all local repositories."
          (base (and base (file-directory-p base) base))
          (choices
           (delete-dups
-           (--mapcat
-            (cons (concat "/" it)
-                  (and-let* ((ext (file-name-extension it)))
-                    (list (concat "/" (file-name-directory it) "*." ext)
-                          (concat "*." ext))))
+           (mapcan
+            (lambda (file)
+              (cons (concat "/" file)
+                    (and-let* ((ext (file-name-extension file)))
+                      (list (concat "/" (file-name-directory file) "*." ext)
+                            (concat "*." ext)))))
             (sort (nconc
                    (magit-untracked-files nil base)
                    ;; The untracked section of the status buffer lists
